@@ -1,17 +1,17 @@
 /****************************************************************************
-** 
+**
 ** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
-** 
+**
 ** This file is part of a Qt Solutions component.
 **
-** Commercial Usage  
+** Commercial Usage
 ** Licensees holding valid Qt Commercial licenses may use this file in
 ** accordance with the Qt Solutions Commercial License Agreement provided
 ** with the Software or, alternatively, in accordance with the terms
 ** contained in a written agreement between you and Nokia.
-** 
+**
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
 ** General Public License version 2.1 as published by the Free Software
@@ -19,49 +19,48 @@
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU Lesser General Public License version 2.1 requirements
 ** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-** 
+**
 ** In addition, as a special exception, Nokia gives you certain
 ** additional rights. These rights are described in the Nokia Qt LGPL
 ** Exception version 1.1, included in the file LGPL_EXCEPTION.txt in this
 ** package.
-** 
-** GNU General Public License Usage 
+**
+** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
 ** General Public License version 3.0 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU General Public License version 3.0 requirements will be
 ** met: http://www.gnu.org/copyleft/gpl.html.
-** 
+**
 ** Please note Third Party Software included with Qt Solutions may impose
 ** additional restrictions and it is the user's responsibility to ensure
 ** that they have met the licensing requirements of the GPL, LGPL, or Qt
 ** Solutions Commercial license and the relevant license of the Third
 ** Party Software they are using.
-** 
+**
 ** If you are unsure which license is appropriate for your use, please
 ** contact Nokia at qt-info@nokia.com.
-** 
+**
 ****************************************************************************/
 
-#include <QtGui/QApplication>
-#include <QtGui/QDesktopWidget>
-#include <QtGui/QPainter>
-#include <QtGui/QPushButton>
-#include <QtGui/QColorDialog>
+#include <QApplication>
+#include <QPainter>
+#include <QPushButton>
+#include <QColorDialog>
 #include <QtCore/QMap>
-#include <QtGui/QLayout>
-#include <QtGui/QStyle>
-#include <QtGui/QLabel>
-#include <QtGui/QToolTip>
-#include <QtGui/QPixmap>
-#include <QtGui/QFocusEvent>
-#include <QtGui/QPaintEvent>
-#include <QtGui/QGridLayout>
-#include <QtGui/QHideEvent>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QShowEvent>
-#include <QtGui/QMouseEvent>
+#include <QLayout>
+#include <QStyle>
+#include <QLabel>
+#include <QToolTip>
+#include <QPixmap>
+#include <QFocusEvent>
+#include <QPaintEvent>
+#include <QGridLayout>
+#include <QHideEvent>
+#include <QKeyEvent>
+#include <QShowEvent>
+#include <QMouseEvent>
 #include <math.h>
 
 #include "qtcolorpicker.h"
@@ -132,21 +131,122 @@
     To obtain the color's name, use text().
 */
 
-/*! \class ColorPickerItem
+/*
     A class  that acts very much  like a QPushButton. It's not styled,
     so we  can  expect  the  exact  same    look,  feel and   geometry
     everywhere.     Also,  this  button     always emits   clicked  on
     mouseRelease, even if the mouse button was  not pressed inside the
     widget.
 */
+class ColorPickerButton : public QFrame
+{
+    Q_OBJECT
 
+public:
+    ColorPickerButton(QWidget *parent);
 
-/*! \class ColorPickerPopup
+Q_SIGNALS:
+    void clicked();
+
+protected:
+    void mousePressEvent(QMouseEvent *e);
+    void mouseMoveEvent(QMouseEvent *e);
+    void mouseReleaseEvent(QMouseEvent *e);
+    void keyPressEvent(QKeyEvent *e);
+    void keyReleaseEvent(QKeyEvent *e);
+    void paintEvent(QPaintEvent *e);
+    void focusInEvent(QFocusEvent *e);
+    void focusOutEvent(QFocusEvent *e);
+};
+
+/*
     This class represents each "color" or item in the color grid.
 */
+class ColorPickerItem : public QFrame
+{
+    Q_OBJECT
+
+public:
+    ColorPickerItem(const QColor &color = Qt::white, const QString &text = QString(),
+                      QWidget *parent = 0);
+    ~ColorPickerItem();
+
+    QColor color() const;
+    QString text() const;
+
+    void setSelected(bool);
+    bool isSelected() const;
+Q_SIGNALS:
+    void clicked();
+    void selected();
+
+public Q_SLOTS:
+    void setColor(const QColor &color, const QString &text = QString());
+
+protected:
+    void mousePressEvent(QMouseEvent *e);
+    void mouseReleaseEvent(QMouseEvent *e);
+    void mouseMoveEvent(QMouseEvent *e);
+    void paintEvent(QPaintEvent *e);
+
+private:
+    QColor c;
+    QString t;
+    bool sel;
+};
+
 /*
 
 */
+class ColorPickerPopup : public QFrame
+{
+    Q_OBJECT
+
+public:
+    ColorPickerPopup(int width, bool withColorDialog,
+                       QWidget *parent = 0);
+    ~ColorPickerPopup();
+
+    void insertColor(const QColor &col, const QString &text, int index);
+    void exec();
+
+    void setExecFlag();
+
+    QColor lastSelected() const;
+
+    ColorPickerItem *find(const QColor &col) const;
+    QColor color(int index) const;
+
+Q_SIGNALS:
+    void selected(const QColor &);
+    void hid();
+
+public Q_SLOTS:
+    void getColorFromDialog();
+
+protected Q_SLOTS:
+    void updateSelected();
+
+protected:
+    void keyPressEvent(QKeyEvent *e);
+    void showEvent(QShowEvent *e);
+    void hideEvent(QHideEvent *e);
+    void mouseReleaseEvent(QMouseEvent *e);
+
+    void regenerateGrid();
+
+private:
+    QMap<int, QMap<int, QWidget *> > widgetAt;
+    QList<ColorPickerItem *> items;
+    QGridLayout *grid;
+    ColorPickerButton *moreButton;
+    QEventLoop *eventLoop;
+
+    int lastPos;
+    int cols;
+    QColor lastSel;
+};
+
 /*!
     Constructs a QtColorPicker widget. The popup will display a grid
     with \a cols columns, or if \a cols is -1, the number of columns
@@ -165,7 +265,7 @@
     \sa QFrame
 */
 QtColorPicker::QtColorPicker(QWidget *parent,
-			     int cols, bool enableColorDialog)
+                             int cols, bool enableColorDialog)
     : QPushButton(parent), popup(0), withColorDialog(enableColorDialog)
 {
     setFocusPolicy(Qt::StrongFocus);
@@ -184,12 +284,12 @@ QtColorPicker::QtColorPicker(QWidget *parent,
 
     // Create color grid popup and connect to it.
     popup = new ColorPickerPopup(cols, withColorDialog, this);
-    connect(popup, SIGNAL(selected(const QColor &)),
-	    SLOT(setCurrentColor(const QColor &)));
-    connect(popup, SIGNAL(hid()), SLOT(popupClosed()));
+    connect(popup, &ColorPickerPopup::selected, this,
+            &QtColorPicker::setCurrentColor);
+    connect(popup, &ColorPickerPopup::hid, this, &QtColorPicker::popupClosed);
 
     // Connect this push button's pressed() signal.
-    connect(this, SIGNAL(toggled(bool)), SLOT(buttonPressed(bool)));
+    connect(this, &QAbstractButton::toggled, this, &QtColorPicker::buttonPressed);
 }
 
 /*!
@@ -209,9 +309,9 @@ void QtColorPicker::buttonPressed(bool toggled)
     if (!toggled)
         return;
 
-    const QRect desktop = QApplication::desktop()->geometry();
+    const QRect desktop = this->parentWidget()->geometry();
     // Make sure the popup is inside the desktop.
-    QPoint pos = mapToGlobal(rect().bottomLeft());
+    QPoint pos = rect().bottomLeft();
     if (pos.x() < desktop.left())
        pos.setX(desktop.left());
     if (pos.y() < desktop.top())
@@ -221,7 +321,7 @@ void QtColorPicker::buttonPressed(bool toggled)
        pos.setX(desktop.width() - popup->sizeHint().width());
     if ((pos.y() + popup->sizeHint().height()) > desktop.bottom())
        pos.setY(desktop.bottom() - popup->sizeHint().height());
-    popup->move(pos);
+    popup->move(mapToGlobal(pos));
 
     if (ColorPickerItem *item = popup->find(col))
         item->setSelected(true);
@@ -331,12 +431,12 @@ void QtColorPicker::setStandardColors()
 void QtColorPicker::setCurrentColor(const QColor &color)
 {
     if (col == color || !color.isValid())
-	return;
+        return;
 
     ColorPickerItem *item = popup->find(color);
     if (!item) {
-	insertColor(color, tr("Custom"));
-	item = popup->find(color);
+        insertColor(color, tr("Custom"));
+        item = popup->find(color);
     }
 
     col = color;
@@ -348,7 +448,7 @@ void QtColorPicker::setCurrentColor(const QColor &color)
     repaint();
 
     item->setSelected(true);
-    emit colorChanged(color);
+    Q_EMIT colorChanged(color);
 }
 
 /*!
@@ -361,9 +461,9 @@ void QtColorPicker::insertColor(const QColor &color, const QString &text, int in
 {
     popup->insertColor(color, text, index);
     if (!firstInserted) {
-	col = color;
-	setText(text);
-	firstInserted = true;
+        col = color;
+        setText(text);
+        firstInserted = true;
     }
 }
 
@@ -394,7 +494,7 @@ bool QtColorPicker::colorDialogEnabled() const
     \code
         void Drawer::mouseReleaseEvent(QMouseEvent *e)
         {
-	    if (e->button() & RightButton) {
+            if (e->button() & RightButton) {
                 QColor color = QtColorPicker::getColor(mapToGlobal(e->pos()));
             }
         }
@@ -432,7 +532,7 @@ QColor QtColorPicker::getColor(const QPoint &point, bool allowCustomColors)
     Constructs the popup widget.
 */
 ColorPickerPopup::ColorPickerPopup(int width, bool withColorDialog,
-				       QWidget *parent)
+                                       QWidget *parent)
     : QFrame(parent, Qt::Popup)
 {
     setFrameStyle(QFrame::StyledPanel);
@@ -443,13 +543,13 @@ ColorPickerPopup::ColorPickerPopup(int width, bool withColorDialog,
     cols = width;
 
     if (withColorDialog) {
-	moreButton = new ColorPickerButton(this);
-	moreButton->setFixedWidth(24);
-	moreButton->setFixedHeight(21);
-	moreButton->setFrameRect(QRect(2, 2, 20, 17));
-	connect(moreButton, SIGNAL(clicked()), SLOT(getColorFromDialog()));
+        moreButton = new ColorPickerButton(this);
+        moreButton->setFixedWidth(24);
+        moreButton->setFixedHeight(21);
+        moreButton->setFrameRect(QRect(2, 2, 20, 17));
+        connect(moreButton, &ColorPickerButton::clicked, this, &ColorPickerPopup::getColorFromDialog);
     } else {
-	moreButton = 0;
+        moreButton = 0;
     }
 
     eventLoop = 0;
@@ -476,8 +576,8 @@ ColorPickerPopup::~ColorPickerPopup()
 ColorPickerItem *ColorPickerPopup::find(const QColor &col) const
 {
     for (int i = 0; i < items.size(); ++i) {
-	if (items.at(i) && items.at(i)->color() == col)
-	    return items.at(i);
+        if (items.at(i) && items.at(i)->color() == col)
+            return items.at(i);
     }
 
     return 0;
@@ -513,10 +613,10 @@ void ColorPickerPopup::insertColor(const QColor &col, const QString &text, int i
     }
     item->setFocus();
 
-    connect(item, SIGNAL(selected()), SLOT(updateSelected()));
+    connect(item, &ColorPickerItem::selected, this, &ColorPickerPopup::updateSelected);
 
     if (index == -1)
-	index = items.count();
+        index = items.count();
 
     items.insert((unsigned int)index, item);
     regenerateGrid();
@@ -557,19 +657,19 @@ void ColorPickerPopup::updateSelected()
     QLayoutItem *layoutItem;
     int i = 0;
     while ((layoutItem = grid->itemAt(i)) != 0) {
-	QWidget *w = layoutItem->widget();
-	if (w && w->inherits("ColorPickerItem")) {
-	    ColorPickerItem *litem = reinterpret_cast<ColorPickerItem *>(layoutItem->widget());
-	    if (litem != sender())
-		litem->setSelected(false);
-	}
-	++i;
+        QWidget *w = layoutItem->widget();
+        if (w && w->inherits("ColorPickerItem")) {
+            ColorPickerItem *litem = reinterpret_cast<ColorPickerItem *>(layoutItem->widget());
+            if (litem != sender())
+                litem->setSelected(false);
+        }
+        ++i;
     }
 
     if (sender() && sender()->inherits("ColorPickerItem")) {
-	ColorPickerItem *item = (ColorPickerItem *)sender();
-	lastSel = item->color();
-	emit selected(item->color());
+        ColorPickerItem *item = (ColorPickerItem *)sender();
+        lastSel = item->color();
+        Q_EMIT selected(item->color());
     }
 
     hide();
@@ -581,7 +681,7 @@ void ColorPickerPopup::updateSelected()
 void ColorPickerPopup::mouseReleaseEvent(QMouseEvent *e)
 {
     if (!rect().contains(e->pos()))
-	hide();
+        hide();
 }
 
 /*! \internal
@@ -595,96 +695,96 @@ void ColorPickerPopup::keyPressEvent(QKeyEvent *e)
 
     bool foundFocus = false;
     for (int j = 0; !foundFocus && j < grid->rowCount(); ++j) {
-	for (int i = 0; !foundFocus && i < grid->columnCount(); ++i) {
-	    if (widgetAt[j][i] && widgetAt[j][i]->hasFocus()) {
-		curRow = j;
-		curCol = i;
-		foundFocus = true;
-		break;
-	    }
-	}
+        for (int i = 0; !foundFocus && i < grid->columnCount(); ++i) {
+            if (widgetAt[j][i] && widgetAt[j][i]->hasFocus()) {
+                curRow = j;
+                curCol = i;
+                foundFocus = true;
+                break;
+            }
+        }
     }
 
     switch (e->key()) {
-	case Qt::Key_Left:
-	    if (curCol > 0) --curCol;
-	    else if (curRow > 0) { --curRow; curCol = grid->columnCount() - 1; }
-	    break;
-	case Qt::Key_Right:
-	    if (curCol < grid->columnCount() - 1 && widgetAt[curRow][curCol + 1]) ++curCol;
-	    else if (curRow < grid->rowCount() - 1) { ++curRow; curCol = 0; }
-	    break;
-	case Qt::Key_Up:
-	    if (curRow > 0) --curRow;
-	    else curCol = 0;
-	    break;
-	case Qt::Key_Down:
-	    if (curRow < grid->rowCount() - 1) {
-		QWidget *w = widgetAt[curRow + 1][curCol];
-		if (w) {
-		    ++curRow;
-		} else for (int i = 1; i < grid->columnCount(); ++i) {
-		    if (!widgetAt[curRow + 1][i]) {
-			curCol = i - 1;
-			++curRow;
-			break;
-		    }
-		}
-	    }
-	    break;
-	case Qt::Key_Space:
-	case Qt::Key_Return:
-	case Qt::Key_Enter: {
-	    QWidget *w = widgetAt[curRow][curCol];
-	    if (w && w->inherits("ColorPickerItem")) {
-		ColorPickerItem *wi = reinterpret_cast<ColorPickerItem *>(w);
-		wi->setSelected(true);
+        case Qt::Key_Left:
+            if (curCol > 0) --curCol;
+            else if (curRow > 0) { --curRow; curCol = grid->columnCount() - 1; }
+            break;
+        case Qt::Key_Right:
+            if (curCol < grid->columnCount() - 1 && widgetAt[curRow][curCol + 1]) ++curCol;
+            else if (curRow < grid->rowCount() - 1) { ++curRow; curCol = 0; }
+            break;
+        case Qt::Key_Up:
+            if (curRow > 0) --curRow;
+            else curCol = 0;
+            break;
+        case Qt::Key_Down:
+            if (curRow < grid->rowCount() - 1) {
+                QWidget *w = widgetAt[curRow + 1][curCol];
+                if (w) {
+                    ++curRow;
+                } else for (int i = 1; i < grid->columnCount(); ++i) {
+                    if (!widgetAt[curRow + 1][i]) {
+                        curCol = i - 1;
+                        ++curRow;
+                        break;
+                    }
+                }
+            }
+            break;
+        case Qt::Key_Space:
+        case Qt::Key_Return:
+        case Qt::Key_Enter: {
+            QWidget *w = widgetAt[curRow][curCol];
+            if (w && w->inherits("ColorPickerItem")) {
+                ColorPickerItem *wi = reinterpret_cast<ColorPickerItem *>(w);
+                wi->setSelected(true);
 
-		QLayoutItem *layoutItem;
+                QLayoutItem *layoutItem;
                 int i = 0;
-		while ((layoutItem = grid->itemAt(i)) != 0) {
-		    QWidget *w = layoutItem->widget();
-		    if (w && w->inherits("ColorPickerItem")) {
-			ColorPickerItem *litem
-			    = reinterpret_cast<ColorPickerItem *>(layoutItem->widget());
-			if (litem != wi)
-			    litem->setSelected(false);
-		    }
-		    ++i;
-		}
+                while ((layoutItem = grid->itemAt(i)) != 0) {
+                    QWidget *w = layoutItem->widget();
+                    if (w && w->inherits("ColorPickerItem")) {
+                        ColorPickerItem *litem
+                            = reinterpret_cast<ColorPickerItem *>(layoutItem->widget());
+                        if (litem != wi)
+                            litem->setSelected(false);
+                    }
+                    ++i;
+                }
 
-		lastSel = wi->color();
-		emit selected(wi->color());
-		hide();
-	    } else if (w && w->inherits("QPushButton")) {
-		ColorPickerItem *wi = reinterpret_cast<ColorPickerItem *>(w);
-		wi->setSelected(true);
+                lastSel = wi->color();
+                Q_EMIT selected(wi->color());
+                hide();
+            } else if (w && w->inherits("QPushButton")) {
+                ColorPickerItem *wi = reinterpret_cast<ColorPickerItem *>(w);
+                wi->setSelected(true);
 
-		QLayoutItem *layoutItem;
+                QLayoutItem *layoutItem;
                 int i = 0;
-		while ((layoutItem = grid->itemAt(i)) != 0) {
-		    QWidget *w = layoutItem->widget();
-		    if (w && w->inherits("ColorPickerItem")) {
-			ColorPickerItem *litem
-			    = reinterpret_cast<ColorPickerItem *>(layoutItem->widget());
-			if (litem != wi)
-			    litem->setSelected(false);
-		    }
-		    ++i;
-		}
+                while ((layoutItem = grid->itemAt(i)) != 0) {
+                    QWidget *w = layoutItem->widget();
+                    if (w && w->inherits("ColorPickerItem")) {
+                        ColorPickerItem *litem
+                            = reinterpret_cast<ColorPickerItem *>(layoutItem->widget());
+                        if (litem != wi)
+                            litem->setSelected(false);
+                    }
+                    ++i;
+                }
 
-		lastSel = wi->color();
-		emit selected(wi->color());
-		hide();
-	    }
-	}
-	break;
+                lastSel = wi->color();
+                Q_EMIT selected(wi->color());
+                hide();
+            }
+        }
+        break;
         case Qt::Key_Escape:
             hide();
         break;
-	default:
-	    e->ignore();
-	    break;
+        default:
+            e->ignore();
+            break;
     }
 
     widgetAt[curRow][curCol]->setFocus();
@@ -696,12 +796,12 @@ void ColorPickerPopup::keyPressEvent(QKeyEvent *e)
 void ColorPickerPopup::hideEvent(QHideEvent *e)
 {
     if (eventLoop) {
-	eventLoop->exit();
+        eventLoop->exit();
     }
 
     setFocus();
 
-    emit hid();
+    Q_EMIT hid();
     QFrame::hideEvent(e);
 }
 
@@ -722,23 +822,23 @@ void ColorPickerPopup::showEvent(QShowEvent *)
 {
     bool foundSelected = false;
     for (int i = 0; i < grid->columnCount(); ++i) {
-	for (int j = 0; j < grid->rowCount(); ++j) {
-	    QWidget *w = widgetAt[j][i];
-	    if (w && w->inherits("ColorPickerItem")) {
-		if (((ColorPickerItem *)w)->isSelected()) {
-		    w->setFocus();
-		    foundSelected = true;
-		    break;
-		}
-	    }
-	}
+        for (int j = 0; j < grid->rowCount(); ++j) {
+            QWidget *w = widgetAt[j][i];
+            if (w && w->inherits("ColorPickerItem")) {
+                if (((ColorPickerItem *)w)->isSelected()) {
+                    w->setFocus();
+                    foundSelected = true;
+                    break;
+                }
+            }
+        }
     }
 
     if (!foundSelected) {
-	if (items.count() == 0)
-	    setFocus();
-	else
-	    widgetAt[0][0]->setFocus();
+        if (items.count() == 0)
+            setFocus();
+        else
+            widgetAt[0][0]->setFocus();
     }
 }
 
@@ -751,14 +851,14 @@ void ColorPickerPopup::regenerateGrid()
 
     int columns = cols;
     if (columns == -1)
-	columns = (int) ceil(sqrt((float) items.count()));
+        columns = (int) ceil(sqrt((float) items.count()));
 
     // When the number of columns grows, the number of rows will
     // fall. There's no way to shrink a grid, so we create a new
     // one.
     if (grid) delete grid;
     grid = new QGridLayout(this);
-    grid->setMargin(1);
+    grid->setContentsMargins(1, 1, 1, 1);
     grid->setSpacing(0);
 
     int ccol = 0, crow = 0;
@@ -774,8 +874,8 @@ void ColorPickerPopup::regenerateGrid()
     }
 
     if (moreButton) {
-	grid->addWidget(moreButton, crow, ccol);
-	widgetAt[crow][ccol] = moreButton;
+        grid->addWidget(moreButton, crow, ccol);
+        widgetAt[crow][ccol] = moreButton;
     }
     updateGeometry();
 }
@@ -787,15 +887,13 @@ void ColorPickerPopup::regenerateGrid()
 */
 void ColorPickerPopup::getColorFromDialog()
 {
-    bool ok;
-    QRgb rgb = QColorDialog::getRgba(lastSel.rgba(), &ok, parentWidget());
-    if (!ok)
-	return;
+    QColor col = QColorDialog::getColor(lastSel, parentWidget());
+    if (!col.isValid())
+        return;
 
-    QColor col = QColor::fromRgba(rgb);
     insertColor(col, tr("Custom"), -1);
     lastSel = col;
-    emit selected(col);
+    Q_EMIT selected(col);
 }
 
 /*!
@@ -803,7 +901,7 @@ void ColorPickerPopup::getColorFromDialog()
     whose name is set to \a text.
 */
 ColorPickerItem::ColorPickerItem(const QColor &color, const QString &text,
-				     QWidget *parent)
+                                     QWidget *parent)
     : QFrame(parent), c(color), t(text), sel(false)
 {
     setToolTip(t);
@@ -881,7 +979,7 @@ void ColorPickerItem::mouseMoveEvent(QMouseEvent *)
 void ColorPickerItem::mouseReleaseEvent(QMouseEvent *)
 {
     sel = true;
-    emit selected();
+    Q_EMIT selected();
 }
 
 /*!
@@ -905,14 +1003,14 @@ void ColorPickerItem::paintEvent(QPaintEvent *)
     p.setPen( QPen( Qt::gray, 0, Qt::SolidLine ) );
 
     if (sel)
-	p.drawRect(1, 1, w - 3, h - 3);
+        p.drawRect(1, 1, w - 3, h - 3);
 
     p.setPen( QPen( Qt::black, 0, Qt::SolidLine ) );
     p.drawRect(3, 3, w - 7, h - 7);
     p.fillRect(QRect(4, 4, w - 8, h - 8), QBrush(c));
 
     if (hasFocus())
-	p.drawRect(0, 0, w - 1, h - 1);
+        p.drawRect(0, 0, w - 1, h - 1);
 }
 
 /*!
@@ -949,7 +1047,7 @@ void ColorPickerButton::mouseReleaseEvent(QMouseEvent *)
 {
     setFrameShadow(Raised);
     repaint();
-    emit clicked();
+    Q_EMIT clicked();
 }
 
 /*!
@@ -958,15 +1056,15 @@ void ColorPickerButton::mouseReleaseEvent(QMouseEvent *)
 void ColorPickerButton::keyPressEvent(QKeyEvent *e)
 {
     if (e->key() == Qt::Key_Up
-	|| e->key() == Qt::Key_Down
-	|| e->key() == Qt::Key_Left
-	|| e->key() == Qt::Key_Right) {
-	qApp->sendEvent(parent(), e);
+        || e->key() == Qt::Key_Down
+        || e->key() == Qt::Key_Left
+        || e->key() == Qt::Key_Right) {
+        qApp->sendEvent(parent(), e);
     } else if (e->key() == Qt::Key_Enter || e->key() == Qt::Key_Space || e->key() == Qt::Key_Return) {
-	setFrameShadow(Sunken);
-	update();
+        setFrameShadow(Sunken);
+        update();
     } else {
-	QFrame::keyPressEvent(e);
+        QFrame::keyPressEvent(e);
     }
 }
 
@@ -976,16 +1074,16 @@ void ColorPickerButton::keyPressEvent(QKeyEvent *e)
 void ColorPickerButton::keyReleaseEvent(QKeyEvent *e)
 {
     if (e->key() == Qt::Key_Up
-	|| e->key() == Qt::Key_Down
-	|| e->key() == Qt::Key_Left
-	|| e->key() == Qt::Key_Right) {
-	qApp->sendEvent(parent(), e);
+        || e->key() == Qt::Key_Down
+        || e->key() == Qt::Key_Left
+        || e->key() == Qt::Key_Right) {
+        qApp->sendEvent(parent(), e);
     } else if (e->key() == Qt::Key_Enter || e->key() == Qt::Key_Space || e->key() == Qt::Key_Return) {
-	setFrameShadow(Raised);
-	repaint();
-	emit clicked();
+        setFrameShadow(Raised);
+        repaint();
+        Q_EMIT clicked();
     } else {
-	QFrame::keyReleaseEvent(e);
+        QFrame::keyReleaseEvent(e);
     }
 
 }
@@ -1031,13 +1129,13 @@ void ColorPickerButton::paintEvent(QPaintEvent *e)
     p.drawRect(r.center().x() + offset    , r.center().y() + offset, 1, 1);
     p.drawRect(r.center().x() + offset + 4, r.center().y() + offset, 1, 1);
     if (hasFocus()) {
-	p.setPen( QPen( Qt::black, 0, Qt::SolidLine ) );
-	p.drawRect(0, 0, width() - 1, height() - 1);
+        p.setPen( QPen( Qt::black, 0, Qt::SolidLine ) );
+        p.drawRect(0, 0, width() - 1, height() - 1);
     }
 
     p.end();
 
 }
 
-
-
+#include "qtcolorpicker.moc"
+#include "moc_qtcolorpicker.cpp"
