@@ -1,3 +1,17 @@
+/**
+ *
+ * @file src/parser/ParserFactory.hpp
+ *
+ * @copyright 2008-2024 Bordeaux INP, CNRS (LaBRI UMR 5800), Inria,
+ *                      Univ. Bordeaux. All rights reserved.
+ *
+ * @author Camille Ordronneau
+ * @author Francois Trahay
+ * @author Johnny Jazeix
+ * @author Mathieu Faverge
+ *
+ * @date 2024-07-17
+ */
 #ifndef PARSERFACTORY_HPP
 #define PARSERFACTORY_HPP
 
@@ -5,7 +19,8 @@
  * \class ParserFactory
  * \brief Factory which creates a parser depending on the name passed in argument
  */
-class ParserFactory {
+class ParserFactory
+{
 private:
     ParserFactory();
 
@@ -20,4 +35,4 @@ public:
     static bool create(Parser **parser, const std::string &filename);
 };
 
-#endif // PARSERFACTORY_HPP
+#endif /* PARSERFACTORY_HPP */
