@@ -1,45 +1,19 @@
-/*
-** This file is part of the ViTE project.
-**
-** This software is governed by the CeCILL-A license under French law
-** and abiding by the rules of distribution of free software. You can
-** use, modify and/or redistribute the software under the terms of the
-** CeCILL-A license as circulated by CEA, CNRS and INRIA at the following
-** URL: "http://www.cecill.info".
-** 
-** As a counterpart to the access to the source code and rights to copy,
-** modify and redistribute granted by the license, users are provided
-** only with a limited warranty and the software's author, the holder of
-** the economic rights, and the successive licensors have only limited
-** liability.
-** 
-** In this respect, the user's attention is drawn to the risks associated
-** with loading, using, modifying and/or developing or reproducing the
-** software by the user in light of its specific status of free software,
-** that may mean that it is complicated to manipulate, and that also
-** therefore means that it is reserved for developers and experienced
-** professionals having in-depth computer knowledge. Users are therefore
-** encouraged to load and test the software's suitability as regards
-** their requirements in conditions enabling the security of their
-** systems and/or data to be ensured and, more generally, to use and
-** operate it in the same conditions as regards security.
-** 
-** The fact that you are presently reading this means that you have had
-** knowledge of the CeCILL-A license and that you accept its terms.
-**
-**
-** ViTE developers are (for version 0.* to 1.0):
-**
-**        - COULOMB Kevin
-**        - FAVERGE Mathieu
-**        - JAZEIX Johnny
-**        - LAGRASSE Olivier
-**        - MARCOUEILLE Jule
-**        - NOISETTE Pascal
-**        - REDONDY Arthur
-**        - VUCHENER Clément 
-**
-*/
+/**
+ *
+ * @file src/render/Render_svg.hpp
+ *
+ * @copyright 2008-2024 Bordeaux INP, CNRS (LaBRI UMR 5800), Inria,
+ *                      Univ. Bordeaux. All rights reserved.
+ *
+ * @author Camille Ordronneau
+ * @author Johnny Jazeix
+ * @author Mathieu Faverge
+ * @author Thibault Soucarre
+ * @author Olivier Lagrasse
+ * @author Augustin Degomme
+ *
+ * @date 2024-07-17
+ */
 /*!
  *\file Render_svg.hpp
  */
@@ -50,10 +24,9 @@
 /*!
  * \brief This class redefined the OpenGL widget - QGLWidget - to display the trace.
  */
-class Render_svg :  /*public QGLWidget,*/ public Render_template, public Geometry
+class Render_svg : /*public QGLWidget,*/ public Render, public Geometry
 {
 protected:
-    
     /*!
      * \brief buffer containing the main objets to be displayed
      */
@@ -65,11 +38,8 @@ protected:
     std::ofstream _output_file;
 
     float _red, _green, _blue;
-    
-
 
 public:
-
     /***********************************
      *
      * Constructor and destructor.
@@ -79,23 +49,22 @@ public:
     /*!
      * \brief The default constructor
      */
-    Render_svg(std::string* output_filename);
+    Render_svg(const std::string &output_filename);
 
     /*!
      * \brief The destructor
      */
-    virtual ~Render_svg();
-  
+    ~Render_svg() override;
 
     /*!
      * \brief Proceeds with the initialization of the OpenGL draw functions.
      */
-    void start_draw();
+    void start_draw() override;
 
     /*!
      * \brief Creates and opens the display list for container draws.
      */
-    void start_draw_containers();
+    void start_draw_containers() override;
 
     /*!
      * \brief Draw a container according to the parameters
@@ -114,17 +83,17 @@ public:
      *
      * This function stores text in a list. This list will be display each time the render area need to be updated.
      */
-    void draw_container_text(const Element_pos x, const Element_pos y, const std::string value);
+    void draw_container_text(const Element_pos x, const Element_pos y, const std::string &value);
 
     /*!
      * \brief Closes the container display list.
      */
-    void end_draw_containers();
-     
+    void end_draw_containers() override;
+
     /*!
      * \brief Creates and opens the display list for stater draws.
      */
-    void start_draw_states();
+    void start_draw_states() override;
 
     /*!
      * \brief Draw a state of the trace.
@@ -136,17 +105,17 @@ public:
      * \param g the green color rate of the state.
      * \param b the blue color rate of the state.
      */
-    void draw_state(const Element_pos start , const Element_pos end, const Element_pos base, const Element_pos height, const Element_col r, const Element_col g, const Element_col b);
+    void draw_state(const Element_pos, const Element_pos, const Element_pos, const Element_pos, const Element_pos, EntityValue *) override;
 
     /*!
      * \brief Closes the state display list.
      */
-    void end_draw_states();
+    void end_draw_states() override;
 
     /*!
      * \brief Open the arrow display list.
      */
-    void start_draw_arrows();
+    void start_draw_arrows() override;
 
     /*!
      * \brief Draw an arrow.
@@ -157,12 +126,12 @@ public:
      *
      * This function stores all the information of the arrow to display it each time the render area need to be updated.
      */
-    void draw_arrow(const Element_pos start_time, const Element_pos end_time, const Element_pos start_height, const Element_pos end_height, const Element_col r, const Element_col g, const Element_col b);
+    void draw_arrow(const Element_pos start_time, const Element_pos end_time, const Element_pos start_height, const Element_pos end_height, const Element_col r, const Element_col g, const Element_col b, EntityValue *value) override;
 
     /*!
      * \brief Closes the arrow display list.
      */
-    void end_draw_arrows();
+    void end_draw_arrows() override;
 
     /*!
      * \brief Draw arrows contained in the Arrow_ vector
@@ -170,7 +139,7 @@ public:
      */
     // void draw_stored_arrows(std::vector<Arrow_> &arrows);
 
-    void start_draw_events();
+    void start_draw_events() override;
 
     /*!
      * \brief Draw an event.
@@ -183,9 +152,9 @@ public:
      *
      * This function stores all the information of the event to display it each time the render area need to be updated.
      */
-    void draw_event(const Element_pos time, const Element_pos height,  const Element_pos container_height);
+    void draw_event(const Element_pos time, const Element_pos height, const Element_pos container_height, EntityValue *value) override;
 
-    void end_draw_events();
+    void end_draw_events() override;
     /*!
      * \brief Draw events contained in the Event_ vector
      * \param events An event vector.
@@ -195,8 +164,8 @@ public:
     /*!
      * \brief Creates and opens the display list for counter draws.
      */
-    void start_draw_counter();
-     
+    void start_draw_counter() override;
+
     /*!
      * \brief Draw a point of the counter.
      * \param x x position of the point.
@@ -205,34 +174,34 @@ public:
      * Each time counter is increased, this function is called with the coordinates of the new point.
      */
     void draw_counter(const Element_pos x, const Element_pos y);
-     
+
     /*!
      * \brief Closes the counter display list.
      */
-    void end_draw_counter();
+    void end_draw_counter() override;
 
     /*!
      * \brief Called before ruler drawing.
      */
-    void start_ruler();
-     
+    void start_ruler() override;
+
     /*!
      * \brief Called after ruler drawing.
      */
-    void end_ruler();
+    void end_ruler() override;
 
     /*!
      * \brief Do nothing (it is present for compatibility of the Render class).
      */
-    void end_draw();
+    void end_draw() override;
 
     /*!
      * \brief Set the color for the further drawings.
      * \param r the red value. Within [0 ; 1].
      * \param g the green value. Within [0 ; 1].
-     * \param b the blue value. Within [0 ; 1].   
+     * \param b the blue value. Within [0 ; 1].
      */
-    void set_color(float r, float g, float b);
+    void set_color(float r, float g, float b) override;
 
     /*!
      * \brief Draw a text.
@@ -241,7 +210,7 @@ public:
      * \param z the deep position of the text.
      * \param s the text.
      */
-    virtual void draw_text(const Element_pos x, const Element_pos y, const Element_pos z, const std::string s);
+    void draw_text(const Element_pos x, const Element_pos y, const Element_pos z, const std::string &s) override;
 
     /*!
      * \brief Draw a quad.
@@ -251,7 +220,7 @@ public:
      * \param w the width of the quad.
      * \param h the height of the quad.
      */
-    void draw_quad(Element_pos x, Element_pos y, Element_pos z, Element_pos w, Element_pos h);
+    void draw_quad(Element_pos x, Element_pos y, Element_pos z, Element_pos w, Element_pos h) override;
 
     /*!
      * \brief Draw a triangle.
@@ -261,7 +230,7 @@ public:
      * \param r the rotation of triangle. (clockwise and in degree)
      */
     void draw_triangle(Element_pos x, Element_pos y,
-                       Element_pos size, Element_pos r);
+                       Element_pos size, Element_pos r) override;
 
     /*!
      * \brief Draw a line.
@@ -271,7 +240,7 @@ public:
      * \param y2 the vertical position of the second point.
      * \param z the deep position of the triangle.
      */
-    void draw_line(Element_pos x1, Element_pos y1, Element_pos x2, Element_pos y2, Element_pos z);
+    void draw_line(Element_pos x1, Element_pos y1, Element_pos x2, Element_pos y2, Element_pos z) override;
 
     /*!
      * \brief Draw a circle.
@@ -280,10 +249,40 @@ public:
      * \param z the deep position of the circle.
      * \param r the circle radius.
      */
-    void draw_circle(Element_pos x, Element_pos y, Element_pos z, Element_pos r);
+    void draw_circle(Element_pos x, Element_pos y, Element_pos z, Element_pos r) override;
 
+    /*!
+     * \brief Draw a text with the value of a variable
+     * \param text text to draw.
+     * \param y y position of the point.
+     */
+    void draw_text_value(long int id, double text, double y) override {
+        (void)id;
+        (void)text;
+        (void)y;
+    }
+
+    /*!
+     * \brief draws the vertical helper line
+     */
+
+    void draw_vertical_line() override;
+
+    /*!
+     * \brief slot connected to the simple click event
+     */
+    void update_vertical_line() override;
+
+    /*!
+     * \brief set the vertical line offset
+     * \param l the line offset.
+     */
+    void set_vertical_line(Element_pos l) override;
+
+    /*!
+     * \brief Draw the ruler display list.
+     */
+    void call_ruler() override;
 };
 
-
-
 #endif
